==> tccli-3.0.1090.1.tar.gz: tccli-3.0.1090.1/tccli/examples/csip/v20221121/DescribeAssetViewVulRiskList.md <==
**Example 1: success1**

success1

Input: 

```
tccli csip DescribeAssetViewVulRiskList --cli-unfold-argument ```

Output: 
```
{
    "Response": {
        "Data": [
            {
                "AffectAsset": "182.254.145.158",
                "AppId": "1300448058",
                "AppName": "OpenSSH",
                "AppVersion": "-",
                "CVE": "CVE-2020-15778",
                "CVSS": 0,
                "CWPVersion": 4,
                "Component": "OpenSSH",
                "EMGCVulType": 0,
                "FirstTime": "2023-09-26 16:34:50",
                "From": "云安全中心",
                "HandleTaskId": "",
                "Index": "360bfa2c7c6f118db22f829991424d7a",
                "InstanceId": "ins-kja8dy5r",
                "InstanceName": "[autotest][勿删]自动化测试NAT1",
                "InstanceType": "CVM",
                "InstanceUUID": "7bb60327-47de-4bce-b979-57166dc89c72",
                "Level": "high",
                "Nick": "",
                "PCMGRId": "",
                "POCId": "c808d8eb0e9c322279c2efa3b82a491c",
                "Payload": "OpenSSH/7.4",
                "Port": "22",
                "RecentTime": "2023-09-27 11:49:10",
                "RiskId": "1498f23a853529b3be8cf554629e4533",
                "Status": 0,
                "TaskId": "",
                "Uin": "",
                "VULName": "OpenSSH 命令注入漏洞(CVE-2020-15778)",
                "VULType": "命令注入",
                "VULURL": ""
            },
            {
                "AffectAsset": "42.192.123.209",
                "AppId": "1300448058",
                "AppName": "OpenSSH",
                "AppVersion": "-",
                "CVE": "CVE-2020-15778",
                "CVSS": 0,
                "CWPVersion": 4,
                "Component": "OpenSSH",
                "EMGCVulType": 0,
                "FirstTime": "2023-09-26 16:34:50",
                "From": "云安全中心",
                "HandleTaskId": "",
                "Index": "774b28af351a041b41f246ca43a50b59",
                "InstanceId": "ins-p1jyrg75",
                "InstanceName": "[autotest][勿删]自动化测试VPC",
                "InstanceType": "CVM",
                "InstanceUUID": "bdc338d2-eaaf-4b17-9708-9e9bd26806ae",
                "Level": "high",
                "Nick": "",
                "PCMGRId": "",
                "POCId": "c808d8eb0e9c322279c2efa3b82a491c",
                "Payload": "OpenSSH/8.0",
                "Port": "22",
                "RecentTime": "2023-09-27 11:49:10",
                "RiskId": "1498f23a853529b3be8cf554629e4533",
                "Status": 0,
                "TaskId": "",
                "Uin": "",
                "VULName": "OpenSSH 命令注入漏洞(CVE-2020-15778)",
                "VULType": "命令注入",
                "VULURL": ""
            },
            {
                "AffectAsset": "81.69.38.139",
                "AppId": "1300448058",
                "AppName": "OpenSSH",
                "AppVersion": "-",
                "CVE": "CVE-2020-15778",
                "CVSS": 0,
                "CWPVersion": 4,
                "Component": "OpenSSH",
                "EMGCVulType": 0,
                "FirstTime": "2023-09-26 16:34:50",
                "From": "云安全中心",
                "HandleTaskId": "",
                "Index": "e1399eb478bb080626419625f762d23e",
                "InstanceId": "ins-17ye5faf",
                "InstanceName": "[autotest][勿删]自动化测试VPC",
                "InstanceType": "CVM",
                "InstanceUUID": "9910883f-ca69-41b8-8f41-6b399b30a053",
                "Level": "high",
                "Nick": "",
                "PCMGRId": "",
                "POCId": "c808d8eb0e9c322279c2efa3b82a491c",
                "Payload": "OpenSSH/8.0",
                "Port": "22",
                "RecentTime": "2023-09-27 11:49:10",
                "RiskId": "1498f23a853529b3be8cf554629e4533",
                "Status": 0,
                "TaskId": "",
                "Uin": "",
                "VULName": "OpenSSH 命令注入漏洞(CVE-2020-15778)",
                "VULType": "命令注入",
                "VULURL": ""
            },
            {
                "AffectAsset": "42.192.123.209",
                "AppId": "1300448058",
                "AppName": "Nginx",
                "AppVersion": "-",
                "CVE": "CVE-2019-9511",
                "CVSS": 0,
                "CWPVersion": 4,
                "Component": "Nginx",
                "EMGCVulType": 0,
                "FirstTime": "2023-09-26 16:34:50",
                "From": "云安全中心",
                "HandleTaskId": "",
                "Index": "fed411b4775d7f46cd192a45e2877f0b",
                "InstanceId": "ins-p1jyrg75",
                "InstanceName": "[autotest][勿删]自动化测试VPC",
                "InstanceType": "CVM",
                "InstanceUUID": "bdc338d2-eaaf-4b17-9708-9e9bd26806ae",
                "Level": "high",
                "Nick": "",
                "PCMGRId": "",
                "POCId": "654f82856a1f02e61941529f4d7bb642",
                "Payload": "nginx/1.14.1",
                "Port": "80",
                "RecentTime": "2023-09-27 11:49:10",
                "RiskId": "28d5b79163e64cd046e6537131ea9e08",
                "Status": 0,
                "TaskId": "",
                "Uin": "",
                "VULName": "nginx 安全漏洞(CVE-2019-9511)",
                "VULType": "其他",
                "VULURL": ""
            },
            {
                "AffectAsset": "81.69.38.139",
                "AppId": "1300448058",
                "AppName": "Nginx",
                "AppVersion": "-",
                "CVE": "CVE-2019-9511",
                "CVSS": 0,
                "CWPVersion": 4,
                "Component": "Nginx",
                "EMGCVulType": 0,
                "FirstTime": "2023-09-26 16:34:50",
                "From": "云安全中心",
                "HandleTaskId": "",
                "Index": "3b4a757f4f20274df5afbf45a9fd961b",
                "InstanceId": "ins-17ye5faf",
                "InstanceName": "[autotest][勿删]自动化测试VPC",
                "InstanceType": "CVM",
                "InstanceUUID": "9910883f-ca69-41b8-8f41-6b399b30a053",
                "Level": "high",
                "Nick": "",
                "PCMGRId": "",
                "POCId": "654f82856a1f02e61941529f4d7bb642",
                "Payload": "nginx/1.14.1",
                "Port": "80",
                "RecentTime": "2023-09-27 11:49:10",
                "RiskId": "28d5b79163e64cd046e6537131ea9e08",
                "Status": 0,
                "TaskId": "",
                "Uin": "",
                "VULName": "nginx 安全漏洞(CVE-2019-9511)",
                "VULType": "其他",
                "VULURL": ""
            },
            {
                "AffectAsset": "42.192.123.209",
                "AppId": "1300448058",
                "AppName": "Nginx",
                "AppVersion": "-",
                "CVE": "CVE-2022-41742",
                "CVSS": 0,
                "CWPVersion": 4,
                "Component": "Nginx",
                "EMGCVulType": 0,
                "FirstTime": "2023-09-26 16:34:50",
                "From": "云安全中心",
                "HandleTaskId": "",
                "Index": "f71a76c67fdfdcfed6164d37a163f3ee",
                "InstanceId": "ins-p1jyrg75",
                "InstanceName": "[autotest][勿删]自动化测试VPC",
                "InstanceType": "CVM",
                "InstanceUUID": "bdc338d2-eaaf-4b17-9708-9e9bd26806ae",
                "Level": "high",
                "Nick": "",
                "PCMGRId": "",
                "POCId": "62fb737e4fcabde555e911e4cab32b6a",
                "Payload": "nginx/1.14.1",
                "Port": "80",
                "RecentTime": "2023-09-27 11:49:10",
                "RiskId": "367a544eab01c874b7db69491d78e6d2",
                "Status": 0,
                "TaskId": "",
                "Uin": "",
                "VULName": "nginx 越界写入漏洞（CVE-2022-41742）",
                "VULType": "处理逻辑错误",
                "VULURL": ""
            },
            {
                "AffectAsset": "81.69.38.139",
                "AppId": "1300448058",
                "AppName": "Nginx",
                "AppVersion": "-",
                "CVE": "CVE-2022-41742",
                "CVSS": 0,
                "CWPVersion": 4,
                "Component": "Nginx",
                "EMGCVulType": 0,
                "FirstTime": "2023-09-26 16:34:50",
                "From": "云安全中心",
                "HandleTaskId": "",
                "Index": "8b915d789892bf6ecc516f4e98912c39",
                "InstanceId": "ins-17ye5faf",
                "InstanceName": "[autotest][勿删]自动化测试VPC",
                "InstanceType": "CVM",
                "InstanceUUID": "9910883f-ca69-41b8-8f41-6b399b30a053",
                "Level": "high",
                "Nick": "",
                "PCMGRId": "",
                "POCId": "62fb737e4fcabde555e911e4cab32b6a",
                "Payload": "nginx/1.14.1",
                "Port": "80",
                "RecentTime": "2023-09-27 11:49:10",
                "RiskId": "367a544eab01c874b7db69491d78e6d2",
                "Status": 0,
                "TaskId": "",
                "Uin": "",
                "VULName": "nginx 越界写入漏洞（CVE-2022-41742）",
                "VULType": "处理逻辑错误",
                "VULURL": ""
            },
            {
                "AffectAsset": "42.192.123.209",
                "AppId": "1300448058",
                "AppName": "-",
                "AppVersion": "-",
                "CVE": "-",
                "CVSS": 0,
                "CWPVersion": 4,
                "Component": "",
                "EMGCVulType": 0,
                "FirstTime": "2023-09-26 16:41:07",
                "From": "云安全中心",
                "HandleTaskId": "",
                "Index": "9f7b3ab47fcf97820bdd1d20cec0f5da",
                "InstanceId": "ins-p1jyrg75",
                "InstanceName": "[autotest][勿删]自动化测试VPC",
                "InstanceType": "CVM",
                "InstanceUUID": "bdc338d2-eaaf-4b17-9708-9e9bd26806ae",
                "Level": "high",
                "Nick": "",
                "PCMGRId": "",
                "POCId": "85fa1a25269ee51318abe17dbd7319be",
                "Payload": "username:, password:, nlstResult:['pub'] ",
                "Port": "80",
                "RecentTime": "2023-09-27 11:55:39",
                "RiskId": "3fd56b7aa90aa2d82dc5a09e16a3dc6c",
                "Status": 0,
                "TaskId": "",
                "Uin": "",
                "VULName": "检测到目标FTP服务可匿名访问",
                "VULType": "未授权访问",
                "VULURL": "http://42.192.123.209/"
            },
            {
                "AffectAsset": "42.192.123.209",
                "AppId": "1300448058",
                "AppName": "Nginx",
                "AppVersion": "-",
                "CVE": "CVE-2021-23017",
                "CVSS": 0,
                "CWPVersion": 4,
                "Component": "Nginx",
                "EMGCVulType": 0,
                "FirstTime": "2023-09-26 16:34:50",
                "From": "云安全中心",
                "HandleTaskId": "",
                "Index": "5af1a3e8be94b821f9f88ba1275e0eb1",
                "InstanceId": "ins-p1jyrg75",
                "InstanceName": "[autotest][勿删]自动化测试VPC",
                "InstanceType": "CVM",
                "InstanceUUID": "bdc338d2-eaaf-4b17-9708-9e9bd26806ae",
                "Level": "high",
                "Nick": "",
                "PCMGRId": "",
                "POCId": "b6b554295a36babb8f5dd308ab91e7a0",
                "Payload": "nginx/1.14.1",
                "Port": "80",
                "RecentTime": "2023-09-27 11:49:10",
                "RiskId": "4a2c3dfabf00f0f67e2bf6af373eb0d8",
                "Status": 0,
                "TaskId": "",
                "Uin": "",
                "VULName": "nginx 安全漏洞(CVE-2021-23017)",
                "VULType": "其他",
                "VULURL": ""
            },
            {
                "AffectAsset": "81.69.38.139",
                "AppId": "1300448058",
                "AppName": "Nginx",
                "AppVersion": "-",
                "CVE": "CVE-2021-23017",
                "CVSS": 0,
                "CWPVersion": 4,
                "Component": "Nginx",
                "EMGCVulType": 0,
                "FirstTime": "2023-09-26 16:34:50",
                "From": "云安全中心",
                "HandleTaskId": "",
                "Index": "5324188b8413cec59971463187276526",
                "InstanceId": "ins-17ye5faf",
                "InstanceName": "[autotest][勿删]自动化测试VPC",
                "InstanceType": "CVM",
                "InstanceUUID": "9910883f-ca69-41b8-8f41-6b399b30a053",
                "Level": "high",
                "Nick": "",
                "PCMGRId": "",
                "POCId": "b6b554295a36babb8f5dd308ab91e7a0",
                "Payload": "nginx/1.14.1",
                "Port": "80",
                "RecentTime": "2023-09-27 11:49:10",
                "RiskId": "4a2c3dfabf00f0f67e2bf6af373eb0d8",
                "Status": 0,
                "TaskId": "",
                "Uin": "",
                "VULName": "nginx 安全漏洞(CVE-2021-23017)",
                "VULType": "其他",
                "VULURL": ""
            }
        ],
        "FromLists": [
            {
                "Text": "云安全中心",
                "Value": "0"
            },
            {
                "Text": "主机检测",
                "Value": "1"
            },
            {
                "Text": "容器检测",
                "Value": "5"
            }
        ],
        "InstanceTypeLists": [
            {
                "Text": "CVM",
                "Value": "CVM"
            }
        ],
        "LevelLists": [
            {
                "Text": "严重",
                "Value": "extreme"
            },
            {
                "Text": "高危",
                "Value": "high"
            },
            {
                "Text": "中危",
                "Value": "middle"
            },
            {
                "Text": "低危",
                "Value": "low"
            },
            {
                "Text": "提示",
                "Value": "info"
            }
        ],
        "RequestId": "3c68de67-9f7e-442d-b1f0-81191bd1026e",
        "StatusLists": [
            {
                "Text": "未处理",
                "Value": "0"
            },
            {
                "Text": "标记已处置",
                "Value": "1"
            },
            {
                "Text": "已忽略",
                "Value": "2"
            },
            {
                "Text": "已修复",
                "Value": "3"
            }
        ],
        "Tags": [
            {
                "Text": "该漏洞存在在野利用或在野攻击",
                "Value": "KNOWN_EXPLOITED"
            },
            {
                "Text": "该漏洞仅能本地利用",
                "Value": "LOCAL"
            },
            {
                "Text": "该漏洞可作为系统组件漏洞检出",
                "Value": "SYS"
            },
            {
                "Text": "该漏洞可作为应用组件漏洞检出",
                "Value": "APP"
            },
            {
                "Text": "应急",
                "Value": "IS_EMERGENCY"
            },
            {
                "Text": "该漏洞可以远程利用",
                "Value": "NETWORK"
            },
            {
                "Text": "该漏洞有poc",
                "Value": "POC"
            },
            {
                "Text": "必修",
                "Value": "IS_SUGGEST"
            },
            {
                "Text": "该漏洞有exp",
                "Value": "EXP"
            }
        ],
        "TotalCount": 1102,
        "VULTypeLists": [
            {
                "Text": "处理逻辑错误",
                "Value": "处理逻辑错误"
            }
        ]
    }
}
```

==> tccli-3.0.1102.1.tar.gz: tccli-3.0.1102.1/tccli/examples/csip/v20221121/DescribeAssetViewVulRiskList.md <==
**Example 1: success1**

success1

Input: 

```
tccli csip DescribeAssetViewVulRiskList --cli-unfold-argument ```

Output: 
```
{
    "Response": {
        "Data": [
            {
                "AffectAsset": "182.254.145.158",
                "AppId": "1300448058",
                "AppName": "OpenSSH",
                "AppVersion": "-",
                "CVE": "CVE-2020-15778",
                "CVSS": 0,
                "CWPVersion": 4,
                "Component": "OpenSSH",
                "EMGCVulType": 0,
                "FirstTime": "2023-09-26 16:34:50",
                "From": "云安全中心",
                "HandleTaskId": "",
                "Index": "360bfa2cxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
                "InstanceId": "ins-xxx",
                "InstanceName": "[autotest][勿删]自动化测试NAT1",
                "InstanceType": "CVM",
                "InstanceUUID": "7bb60327-xxxx-xxxx-xxxx-xxxxxxxxxxxx",
                "Level": "high",
                "Nick": "",
                "PCMGRId": "",
                "POCId": "c808d8ebxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
                "Payload": "OpenSSH/7.4",
                "Port": "22",
                "RecentTime": "2023-09-27 11:49:10",
                "RiskId": "1498f23axxxxxxxxxxxxxxxxxxxxxxxxxxx",
                "Status": 0,
                "TaskId": "",
                "Uin": "",
                "VULName": "OpenSSH 命令注入漏洞(CVE-2020-15778)",
                "VULType": "命令注入",
                "VULURL": ""
            }
        ],
        "FromLists": [
            {
                "Text": "云安全中心",
                "Value": "0"
            },
            {
                "Text": "主机检测",
                "Value": "1"
            },
            {
                "Text": "容器检测",
                "Value": "5"
            }
        ],
        "InstanceTypeLists": [
            {
                "Text": "CVM",
                "Value": "CVM"
            }
        ],
        "LevelLists": [
            {
                "Text": "严重",
                "Value": "extreme"
            },
            {
                "Text": "高危",
                "Value": "high"
            },
            {
                "Text": "中危",
                "Value": "middle"
            },
            {
                "Text": "低危",
                "Value": "low"
            },
            {
                "Text": "提示",
                "Value": "info"
            }
        ],
        "RequestId": "3c68de67-9f7e-442d-b1f0-81191bd1026e",
        "StatusLists": [
            {
                "Text": "未处理",
                "Value": "0"
            },
            {
                "Text": "标记已处置",
                "Value": "1"
            },
            {
                "Text": "已忽略",
                "Value": "2"
            },
            {
                "Text": "已修复",
                "Value": "3"
            }
        ],
        "Tags": [
            {
                "Text": "该漏洞存在在野利用或在野攻击",
                "Value": "KNOWN_EXPLOITED"
            },
            {
                "Text": "该漏洞仅能本地利用",
                "Value": "LOCAL"
            },
            {
                "Text": "该漏洞可作为系统组件漏洞检出",
                "Value": "SYS"
            },
            {
                "Text": "该漏洞可作为应用组件漏洞检出",
                "Value": "APP"
            },
            {
                "Text": "应急",
                "Value": "IS_EMERGENCY"
            },
            {
                "Text": "该漏洞可以远程利用",
                "Value": "NETWORK"
            },
            {
                "Text": "该漏洞有poc",
                "Value": "POC"
            },
            {
                "Text": "必修",
                "Value": "IS_SUGGEST"
            },
            {
                "Text": "该漏洞有exp",
                "Value": "EXP"
            }
        ],
        "TotalCount": 1102,
        "VULTypeLists": [
            {
                "Text": "处理逻辑错误",
                "Value": "处理逻辑错误"
            }
        ]
    }
}
```
